Learn R Programming

Rramas (version 0.1-8)

as.tmatrix: Population Transition Matrix

Description

Convert a matrix to transition matrix (class tmatrix) and display some of its properties.

Usage

as.tmatrix(x, names.st = NULL, ...)
# S3 method for tmatrix
plot(x, ...)
# S3 method for tmatrix
print(x, ...)
# S3 method for tmatrix
summary(object, ...)
# S3 method for summary.tmatrix
print(x, ...)

Value

as.tmatrix returns a matrix of class tmatrix.

summary.tmatrix prints the main parameters of the transition matrix: the finite rate of increase ("lambda"), the stable stage distribution, the reproductive value and the sensitivities and elasticities matrices.

plot.tmatrix draw barplots of the stable stage distribution and the reproductive value and plot also a diagram of the life stage cycle.

Arguments

x

For as.tmatrix, x is a square matrix,; for the plot, print and summary methods,x is a matrix of class tmatrix.

object

An object of class tmatrix, i.e, resulting from as.tmatrix.

names.st

A vector of names to rename the rows and columns of the transition matrix.

...

Other parameters passed to print and plot methods.

Author

Marcelino de la Cruz Rot

Details

The purpose of as.tmatrix is to class a transition matrix as an object of class tmatrix, allowing the use of specific methods for transition matrices.

References

Akcakaya, H. R., Burgman, M. A. and Ginzburg L.R. 1999. Applied Population Ecology. Sinauer.

Caswell, H. 2003. Matrix Population Models: Construction, Analysis, and Interpretation . Sinauer.

Examples

Run this code

  data(coryphanthaA)
  coryphanthaA
  coryphanthaA <- as.tmatrix(coryphanthaA)
  summary(coryphanthaA)
  plot(coryphanthaA) 
  

Run the code above in your browser using DataLab