as.tmatrix returns a matrix of class tmatrix.
summary.tmatrix prints the main parameters of the transition matrix:
the finite rate of increase ("lambda"), the stable stage distribution, the
reproductive value and the sensitivities and elasticities matrices.
plot.tmatrix draw barplots of the stable stage distribution and the
reproductive value and plot also a diagram of the life stage cycle.